@@ -22,7 +22,12 @@ header("Pragma: no-cache");
 
 header('Cache-control: private', false);
 header('Content-Type: application/CSV');
-header('Content-Disposition: attachment; filename="' . $username . '-addresses.csv"');
+if(preg_match('/MSIE 5.5/',$_ENV['HTTP_USER_AGENT']) ||
+   preg_match('/MSIE 6.0/',$_ENV['HTTP_USER_AGENT'])) {
+    header('Content-Disposition: filename="' . $username . '-addresses.csv"');
+} else {
+    header('Content-Disposition: attachment; filename="' . $username . '-addresses.csv"');
+}
 
 foreach($rows as $row) {
 	echo implode(',', array_slice($row, 0, -2)) . "\n";
