@@ -89,7 +89,7 @@ if (!$finish) {
      exit;
    }
    
-   while ($csvarray = fgetcsv($csvfile,4096)) { 
+   while ($csvarray = fgetcsv($csvfile,$smusercsv['size'])) { 
       // Let fgetcsv deal with splitting the line into it's parts. (I.E. it deals with quoted commas right. 
       $temp = CSVProcess($csvarray);
       
@@ -112,9 +112,24 @@ if (!$finish) {
 
    echo '
    <FORM METHOD="post" action="' . $PHP_SELF . '">
-   <INPUT TYPE="submit" NAME="finish" VALUE="Finish" TABINDEX="4">
-   <CENTER><TABLE WIDTH="95%" FRAME="void" CELLSPACING="1">
-   ';    // user's data table
+   <INPUT TYPE="submit" NAME="finish" VALUE="Finish" TABINDEX="4">';
+    echo "<br>\n";
+    echo _("Add to addressbook:")." ";
+    $abook = addressbook_init(true, true);
+    if ( $abook->numbackends > 1 ) {
+	echo "<select name=backend>";
+	$backends = $abook->get_backend_list();
+	while (list($undef,$v) = each($backends)) {
+	    if ($v->writeable) {
+		echo '<OPTION VALUE=' . $v->bnum;
+		echo '>' . $v->sname . "\n";
+	    }
+	}
+	echo "</select>";
+    } else {
+	echo '<input type=hidden name=backend value=1>';
+    }
+   echo '<CENTER><TABLE WIDTH="95%" FRAME="void" CELLSPACING="1">';    // user's data table
 
    // Here I will create the headers that I want.
    echo '
@@ -228,10 +243,18 @@ if (!$finish) {
          $addaddr['email'] 	= $_SESSION['csvdata'][$row][3];
          $addaddr['label'] 	= $_SESSION['csvdata'][$row][4];
 
+        if (isset($_POST['backend'])) {                                                                                                                            
+         if (false == $abook->add($addaddr,$_POST['backend'])) {
+            $errorstring .= $abook->error . "<br>\n";
+            $error++;
+         }
+        } else {                                                                                                                                          
          if (false == $abook->add($addaddr,$abook->localbackend)) {
             $errorstring .= $abook->error . "<br>\n";
             $error++;
          }
+        }
+
 
          unset($addaddr); // Also so we don't get any weird information from previous rows
       }
